#
# spec file for package libsepol
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libsepol
Version:        2.5
Release:        3.15
Url:            http://www.nsa.gov/selinux/
Summary:        SELinux binary policy manipulation library
License:        LGPL-2.1+
Group:          System/Libraries
Source:         https://raw.githubusercontent.com/wiki/SELinuxProject/selinux/files/releases/20160223/%{name}-%{version}.tar.gz
Source2:        baselibs.conf
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  flex
BuildRequires:  pkg-config

%description
Security-enhanced Linux is a feature of the Linux(R) kernel and a
number of utilities with enhanced security functionality designed to
add mandatory access controls to Linux.  The Security-enhanced Linux
kernel contains new architectural components originally developed to
improve the security of the Flask operating system. These architectural
components provide general support for the enforcement of many kinds of
mandatory access control policies, including those based on the
concepts of Type Enforcement(R), Role-based Access Control, and
Multi-level Security.

libsepol provides an API for the manipulation of SELinux binary
policies. It is used by checkpolicy (the policy compiler) and similar
tools, as well as by programs like load_policy that need to perform
specific transformations on binary policies such as customizing policy
boolean settings.



%package -n libsepol1
Summary:        SELinux binary policy manipulation library
Group:          System/Libraries

%description -n libsepol1
Security-enhanced Linux is a feature of the Linux(R) kernel and a
number of utilities with enhanced security functionality designed to
add mandatory access controls to Linux.  The Security-enhanced Linux
kernel contains new architectural components originally developed to
improve the security of the Flask operating system. These architectural
components provide general support for the enforcement of many kinds of
mandatory access control policies, including those based on the
concepts of Type Enforcement(R), Role-based Access Control, and
Multi-level Security.

libsepol provides an API for the manipulation of SELinux binary
policies. It is used by checkpolicy (the policy compiler) and similar
tools, as well as by programs like load_policy that need to perform
specific transformations on binary policies such as customizing policy
boolean settings.



%package devel
Summary:        Development Include Files and Libraries for SELinux policy manipulation
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libsepol1 = %{version}
Requires:       pkg-config

%description devel
The libsepol-devel package contains the libraries and header
files needed for developing applications that manipulate binary
policies.



%package devel-static
Summary:        Development Include Files and Libraries for SELinux policy manipulation
Group:          Development/Libraries/C and C++
Requires:       libsepol-devel = %{version}

%description devel-static
The libsepol-devel-static package contains the static libraries
needed for developing applications that manipulate binary
policies.



%prep
%setup -q

%build
make %{?_smp_mflags} CC="%{__cc}" CFLAGS="$RPM_OPT_FLAGS $(getconf LFS_CFLAGS)"

%install
mkdir -p $RPM_BUILD_ROOT/%{_lib}
mkdir -p $RPM_BUILD_ROOT%{_libdir}
mkdir -p $RPM_BUILD_ROOT%{_includedir}
mkdir -p $RPM_BUILD_ROOT%{_bindir}
mkdir -p $RPM_BUILD_ROOT%{_mandir}/man{3,8}
make DESTDIR="$RPM_BUILD_ROOT" LIBDIR="$RPM_BUILD_ROOT%{_libdir}" SHLIBDIR="$RPM_BUILD_ROOT/%{_lib}" install
rm -f $RPM_BUILD_ROOT%{_bindir}/genpolbools
rm -f $RPM_BUILD_ROOT%{_bindir}/genpolusers
rm -f $RPM_BUILD_ROOT%{_bindir}/chkcon
rm -rf $RPM_BUILD_ROOT%{_mandir}/man8

%post -n libsepol1 -p /sbin/ldconfig

%postun -n libsepol1 -p /sbin/ldconfig

%files -n libsepol1
%defattr(-,root,root)
/%{_lib}/libsepol.so.*

%files devel
%defattr(-,root,root)
%{_libdir}/libsepol.so
%{_mandir}/man3/*
%dir %{_includedir}/sepol
%dir %{_includedir}/sepol/cil
%{_includedir}/sepol/*.h
%{_includedir}/sepol/cil/cil.h
%dir %{_includedir}/sepol/policydb
%{_includedir}/sepol/policydb/*.h
%{_libdir}/pkgconfig/libsepol.pc

%files devel-static
%defattr(-,root,root)
%{_libdir}/libsepol.a

%changelog
* Thu Jul 14 2016 jsegitz@novell.com
- Without bug number no submit to SLE 12 SP2 is possible, so to make
  sle-changelog-checker happy: bsc#988977
* Thu Jul 14 2016 jsegitz@novell.com
- Adjusted source link
* Tue Jul  5 2016 i@marguerite.su
- update version 2.5
  * Fix unused variable annotations
  * Fix uninitialized variable in CIL
  * Validate extended avrules and permissionxs in CIL
  * Add support in CIL for neverallowx
  * Fully expand neverallowxperm rules
  * Add support for unordered classes to CIL
  * Add neverallow support for ioctl extended permissions
  * Improve CIL block and macro call recursion detection
  * Fix CIL uninitialized false positive in cil_binary
  * Provide error in CIL if classperms are empty
  * Add userattribute{set} functionality to CIL
  * fix CIL blockinherit copying segfault and add macro restrictions
  * fix CIL NULL pointer dereference when copying classpermission/set
  * Add CIL support for ioctl whitelists
  * Fix memory leak when destroying avtab
  * Replace sscanf in module_to_cil
  * Improve CIL resolution error messages
  * Fix policydb_read for policy versions < 24
  * Added CIL bounds checking and refactored CIL Neverallow checking
  * Refactored libsepol Neverallow and bounds (hierarchy) checking
  * Treat types like an attribute in the attr_type_map
  * Add new ebitmap function named ebitmap_match_any()
  * switch operations to extended perms
  * Write auditadm_r and secadm_r roles to base module when writing CIL
  * Fix module to CIL to only associate declared roleattributes with in-scope types
  * Don't allow categories/sensitivities inside blocks in CIL
  * Replace fmemopen() with internal function in libsepol
  * Verify users prior to evaluating users in cil
  * Binary modules do not support ioctl rules
  * Add support for ioctl command whitelisting
  * Don't use symbol versioning for static object files
  * Add sepol_module_policydb_to_cil(), sepol_module_package_to_cil(),
    and sepol_ppfile_to_module_package()
  * Move secilc out of libsepol
  * fix building Xen policy with devicetreecon, and add devicetreecon
    CIL documentation
  * bool_copy_callback set state on creation
  * Add device tree ocontext nodes to Xen policy
  * Widen Xen IOMEM context entries
  * Fix error path in mls_semantic_level_expand()
  * Update to latest CIL, includes new name resolution and fixes ordering
    issues with blockinherit statements, and bug fixes
- changes in 2.4
  * Remove assumption that SHLIBDIR is ../../ relative to LIBDIR
  * Fix bugs found by hardened gcc flags
  * Build CIL into libsepol. libsepol can be built without CIL by setting the
    DISABLE_CIL flag to 'y'
  * Add an API function to set target_platform
  * Report all neverallow violations
  * Improve check_assertions performance
  * Allow libsepol C++ static library on device
* Fri May 16 2014 vcizek@suse.com
- update to 2.3
  * Improve error message for name-based transition conflicts.
  * Revert libsepol: filename_trans: use some better sorting to compare and merge.
  * Report source file and line information for neverallow failures.
  * Fix valgrind errors in constraint_expr_eval_reason from Richard Haines.
  * Add sepol_validate_transition_reason_buffer function from Richard Haines.
- dropped libsepol-2.1.4-role_fix_callback.patch (upstream)
* Thu Oct 31 2013 p.drouand@gmail.com
- Update to version 2.2
  * Allow constraint denial cause to be determined
  - Add kernel policy version 29.
  - Add modular policy version 17.
  - Add sepol_compute_av_reason_buffer(), sepol_string_to_security
    _class(), sepol_string_to_av_perm().
  * Support overriding Makefile RANLIB
  * Fix man pages
- Remove libsepol-rhat.patch; merged on upstream
* Thu Jun 27 2013 vcizek@suse.com
- change the source url to the official 2.1.9 release tarball
* Sat Jun 22 2013 crrodriguez@opensuse.org
- Build with LFS_CFLAGS for 32 bit archs
* Fri Apr  5 2013 vcizek@suse.com
- remove a debugging artifact in spec
* Thu Apr  4 2013 vcizek@suse.com
- fixed source url
* Wed Feb 13 2013 vcizek@suse.com
- update to 2.1.9
  * filename_trans: use some better sorting to compare and merge
  * coverity fixes
  * implement default type policy syntax
  * Fix memory leak issues found by Klocwork
- added libsepol-rhat.patch
* Mon Jan  7 2013 jengelh@inai.de
- Remove obsolete defines/sections
* Mon Dec 10 2012 p.drouand@gmail.com
- Update to 2.1.8 version:
  * fix neverallow checking on attributes
  * Move context_copy() after switch block in ocontext_copy_*().
  * check for missing initial SID labeling statement.
  * Add always_check_network policy capability
  * role_fix_callback skips out-of-scope roles during expansion.
* Thu Oct 25 2012 vcizek@suse.com
- skip roles which are out of scope when expanding attributes
- needed for building selinux-policy
* Wed Jul 25 2012 meissner@suse.com
- updated to 2.1.4
  - lots of updates
* Wed Oct  5 2011 uli@suse.com
- cross-build fix: use %%__cc macro
* Mon Jun 28 2010 jengelh@medozas.de
- use %%_smp_mflags
* Sat Apr 24 2010 coolo@novell.com
- buildrequire pkg-config to fix provides
* Thu Feb 25 2010 prusnak@suse.cz
- updated to 2.0.41
  * changes too numerous to list
* Sun Dec 13 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Wed Nov 11 2009 crrodriguez@opensuse.org
- libsepol-devel Requires glibc-devel
* Fri Jun 19 2009 prusnak@suse.cz
- put static library in libsepol-devel-static
* Wed May 27 2009 prusnak@suse.cz
- updated to 2.0.36
  * fix alias field in module format, caused by boundary format
    change from Caleb Case
  * fix boolean state smashing from Joshua Brindle
* Mon Dec  1 2008 prusnak@suse.cz
- updated to 2.0.34
  * add bounds support
  * fix invalid aliases bug
* Wed Oct 22 2008 mrueckert@suse.de
- fix debug_packages_requires define
* Tue Sep 23 2008 prusnak@suse.cz
- require only version, not release [bnc#429053]
* Fri Aug 22 2008 prusnak@suse.cz
- added baselibs.conf file
* Fri Aug  1 2008 ro@suse.de
- fix requires for debuginfo package
* Tue Jul 15 2008 prusnak@suse.cz
- initial version 2.0.32
  * based on Fedora package by Dan Walsh <dwalsh@redhat.com>
